==> jc-1.4.0.tar.gz: soot/util/dot/DotGraphAttribute.c <==
// public class soot.util.dot.DotGraphAttribute

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 94d357637b968dda java_lang_StringBuffer
// @dep_class 28f908b461b109d0 soot_util_dot_DotGraphAttribute

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_lang_StringBuffer
// @dep_header soot_util_dot_DotGraphAttribute

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/lang/StringBuffer.h"
#include "soot/util/dot/DotGraphAttribute.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// java.lang.String id
static _jc_field _jc_soot_util_dot_DotGraphAttribute$field_info$id = {
	.name=		"id",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_soot_util_dot_DotGraphAttribute$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_soot_util_dot_DotGraphAttribute$object, refs[-1].soot_util_dot_DotGraphAttribute.id),
};

// java.lang.String value
static _jc_field _jc_soot_util_dot_DotGraphAttribute$field_info$value = {
	.name=		"value",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_soot_util_dot_DotGraphAttribute$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_soot_util_dot_DotGraphAttribute$object, refs[-1].soot_util_dot_DotGraphAttribute.value),
};

// Fields
static _jc_field *const _jc_soot_util_dot_DotGraphAttribute$fields[] = {
	&_jc_soot_util_dot_DotGraphAttribute$field_info$id,
	&_jc_soot_util_dot_DotGraphAttribute$field_info$value
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(java.lang.String, java.lang.String)
//

static _jc_linenum _jc_soot_util_dot_DotGraphAttribute$linenum_table$_init$a34354cd9552963f[];

static const unsigned char _jc_soot_util_dot_DotGraphAttribute$param_ptypes$_init$a34354cd9552963f[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_soot_util_dot_DotGraphAttribute$param_types$_init$a34354cd9552963f[] = {
	&_jc_java_lang_String$type,
	&_jc_java_lang_String$type
};

_jc_method _jc_soot_util_dot_DotGraphAttribute$method_info$_init$a34354cd9552963f = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/String;Ljava/lang/String;)V",
	.class=			&_jc_soot_util_dot_DotGraphAttribute$type,
	.param_types=		&_jc_soot_util_dot_DotGraphAttribute$param_types$_init$a34354cd9552963f,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_util_dot_DotGraphAttribute$param_ptypes$_init$a34354cd9552963f,
	.signature_hash=	_JC_JLONG(0xa34354cd9552963f),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_util_dot_DotGraphAttribute$method$_init$a34354cd9552963f,
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	3,
	      .table=	_jc_soot_util_dot_DotGraphAttribute$linenum_table$_init$a34354cd9552963f
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_util_dot_DotGraphAttribute, _init$a34354cd9552963f);

void
_jc_soot_util_dot_DotGraphAttribute$method$_init$a34354cd9552963f(_jc_env *const env, _jc_soot_util_dot_DotGraphAttribute$object *this, _jc_java_lang_String$object *param0, _jc_java_lang_String$object *param1)
{
	struct _jc_soot_util_dot_DotGraphAttribute$object *r0;
	struct _jc_java_lang_String$object *r1;
	struct _jc_java_lang_String$object *r2;

	r0 = this;
	r1 = param0;
	r2 = param1;
	_JC_LINE_NUMBER(39);				// 0
	_JC_REF_FIELD(env, r0, soot_util_dot_DotGraphAttribute, id) = r1;
	_JC_LINE_NUMBER(40);				// 1
	_JC_REF_FIELD(env, r0, soot_util_dot_DotGraphAttribute, value) = r2;
	_JC_LINE_NUMBER(41);				// 2
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.String toString()
//

static _jc_linenum _jc_soot_util_dot_DotGraphAttribute$linenum_table$toString$7ea43b33b80a3070[];

static const unsigned char _jc_soot_util_dot_DotGraphAttribute$param_ptypes$toString$7ea43b33b80a3070[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_soot_util_dot_DotGraphAttribute$method_info$toString$7ea43b33b80a3070 = {
	.name=			"toString",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_soot_util_dot_DotGraphAttribute$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_soot_util_dot_DotGraphAttribute$param_ptypes$toString$7ea43b33b80a3070,
	.signature_hash=	_JC_JLONG(0x7ea43b33b80a3070),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_util_dot_DotGraphAttribute$method$toString$7ea43b33b80a3070,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_util_dot_DotGraphAttribute$vtable, soot_util_dot_DotGraphAttribute.toString$7ea43b33b80a3070) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	4,
	      .table=	_jc_soot_util_dot_DotGraphAttribute$linenum_table$toString$7ea43b33b80a3070
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_util_dot_DotGraphAttribute, toString$7ea43b33b80a3070);

_jc_java_lang_String$object *
_jc_soot_util_dot_DotGraphAttribute$method$toString$7ea43b33b80a3070(_jc_env *const env, _jc_soot_util_dot_DotGraphAttribute$object *this)
{
	struct _jc_soot_util_dot_DotGraphAttribute$object *r0;
	struct _jc_java_lang_StringBuffer$object *r1;
	struct _jc_java_lang_String$object *r2;
	_jc_char_array *r3;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	_JC_LINE_NUMBER(44);				// 0
	r1 = _JC_NEW(env, java_lang_StringBuffer);
	r3 = _JC_NEW_PRIM_ARRAY(env, char, 1, 16);
	_JC_REF_FIELD(env, r1, java_lang_StringBuffer, value) = r3;
	_JC_LINE_NUMBER(45);				// 1
	r2 = _JC_REF_FIELD(env, r0, soot_util_dot_DotGraphAttribute, id);
	_JC_INVOKE_NONVIRTUAL(env, java_lang_StringBuffer, append$7d7ff98bb1f0cb55, 0, r1, r2);
	_JC_INVOKE_NONVIRTUAL(env, java_lang_StringBuffer, append$7d7ff98bb1f0cb55, 0, r1, _JC_STRING(env, "="));
	_JC_LINE_NUMBER(47);				// 2
	r2 = _JC_REF_FIELD(env, r0, soot_util_dot_DotGraphAttribute, value);
	_JC_INVOKE_NONVIRTUAL(env, java_lang_StringBuffer, append$7d7ff98bb1f0cb55, 0, r1, r2);
	_JC_LINE_NUMBER(48);				// 3
	r2 = _JC_NEW(env, java_lang_String);
	_JC_INVOKE_NONVIRTUAL(env, java_lang_String, _init$aa54f0755ac8f3ce, 0, r2, r1);
	return r2;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_util_dot_DotGraphAttribute$methods[] = {
	&_jc_soot_util_dot_DotGraphAttribute$method_info$_init$a34354cd9552963f,
	&_jc_soot_util_dot_DotGraphAttribute$method_info$toString$7ea43b33b80a3070
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_util_dot_DotGraphAttribute$instanceof_hash_bucket_80[] = {
	&_jc_soot_util_dot_DotGraphAttribute$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_util_dot_DotGraphAttribute$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_util_dot_DotGraphAttribute$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[80]=	_jc_soot_util_dot_DotGraphAttribute$instanceof_hash_bucket_80,
	[113]=	_jc_soot_util_dot_DotGraphAttribute$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_util_dot_DotGraphAttribute$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/lang/StringBuffer",	_JC_JLONG(0x94d357637b968dda) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_util_dot_DotGraphAttribute$vtype _jc_soot_util_dot_DotGraphAttribute$type = {
    .type= {
	.name=			"soot/util/dot/DotGraphAttribute",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0x28f908b461b109d0),
		.source_file=		"DotGraphAttribute.java",
		.instance_size=		sizeof(_jc_soot_util_dot_DotGraphAttribute$refs) + sizeof(_jc_soot_util_dot_DotGraphAttribute$object),
		.num_virtual_refs=	2,
		.num_fields=		sizeof(_jc_soot_util_dot_DotGraphAttribute$fields) / sizeof(*_jc_soot_util_dot_DotGraphAttribute$fields),
		.fields=		_jc_soot_util_dot_DotGraphAttribute$fields,
		.num_methods=		sizeof(_jc_soot_util_dot_DotGraphAttribute$methods) / sizeof(*_jc_soot_util_dot_DotGraphAttribute$methods),
		.methods=		_jc_soot_util_dot_DotGraphAttribute$methods,
		.instanceof_hash_table=	_jc_soot_util_dot_DotGraphAttribute$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_util_dot_DotGraphAttribute$class_depends) / sizeof(*_jc_soot_util_dot_DotGraphAttribute$class_depends),
		.class_depends=		_jc_soot_util_dot_DotGraphAttribute$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_soot_util_dot_DotGraphAttribute$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_util_dot_DotGraphAttribute= {
	    .toString$7ea43b33b80a3070=
		&_jc_soot_util_dot_DotGraphAttribute$method$toString$7ea43b33b80a3070,
	},
    }
};

==> jc-1.4.5.tar.gz: soot/util/dot/DotGraphAttribute.c <==
// public class soot.util.dot.DotGraphAttribute

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 94d357637b968dda java_lang_StringBuffer
// @dep_class 28f908b461b109d0 soot_util_dot_DotGraphAttribute

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_lang_StringBuffer
// @dep_header soot_util_dot_DotGraphAttribute

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/lang/StringBuffer.h"
#include "soot/util/dot/DotGraphAttribute.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// java.lang.String id
static _jc_field _jc_soot_util_dot_DotGraphAttribute$field_info$id = {
	.name=		"id",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_soot_util_dot_DotGraphAttribute$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_soot_util_dot_DotGraphAttribute$object, refs[-1].soot_util_dot_DotGraphAttribute.id),
};

// java.lang.String value
static _jc_field _jc_soot_util_dot_DotGraphAttribute$field_info$value = {
	.name=		"value",
	.signature=	"Ljava/lang/String;",
	.class=		&_jc_soot_util_dot_DotGraphAttribute$type,
	.type=		&_jc_java_lang_String$type,
	.access_flags=	0,
	.offset=	_JC_OFFSETOF(_jc_soot_util_dot_DotGraphAttribute$object, refs[-1].soot_util_dot_DotGraphAttribute.value),
};

// Fields
static _jc_field *const _jc_soot_util_dot_DotGraphAttribute$fields[] = {
	&_jc_soot_util_dot_DotGraphAttribute$field_info$id,
	&_jc_soot_util_dot_DotGraphAttribute$field_info$value
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(java.lang.String, java.lang.String)
//

static _jc_linenum _jc_soot_util_dot_DotGraphAttribute$linenum_table$_init$a34354cd9552963f[];

static const unsigned char _jc_soot_util_dot_DotGraphAttribute$param_ptypes$_init$a34354cd9552963f[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_soot_util_dot_DotGraphAttribute$param_types$_init$a34354cd9552963f[] = {
	&_jc_java_lang_String$type,
	&_jc_java_lang_String$type
};

_jc_method _jc_soot_util_dot_DotGraphAttribute$method_info$_init$a34354cd9552963f = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/String;Ljava/lang/String;)V",
	.class=			&_jc_soot_util_dot_DotGraphAttribute$type,
	.param_types=		&_jc_soot_util_dot_DotGraphAttribute$param_types$_init$a34354cd9552963f,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_soot_util_dot_DotGraphAttribute$param_ptypes$_init$a34354cd9552963f,
	.signature_hash=	_JC_JLONG(0xa34354cd9552963f),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_util_dot_DotGraphAttribute$method$_init$a34354cd9552963f,
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	3,
	      .table=	_jc_soot_util_dot_DotGraphAttribute$linenum_table$_init$a34354cd9552963f
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_util_dot_DotGraphAttribute, _init$a34354cd9552963f);

void _JC_JCNI_ATTR
_jc_soot_util_dot_DotGraphAttribute$method$_init$a34354cd9552963f(_jc_env *const env, _jc_soot_util_dot_DotGraphAttribute$object *this, _jc_java_lang_String$object *param0, _jc_java_lang_String$object *param1)
{
	struct _jc_soot_util_dot_DotGraphAttribute$object *r0;
	struct _jc_java_lang_String$object *r1;
	struct _jc_java_lang_String$object *r2;

	r0 = this;
	r1 = param0;
	r2 = param1;
	_JC_LINE_NUMBER(39);				// 0
	_JC_REF_FIELD(env, r0, soot_util_dot_DotGraphAttribute, id) = r1;
	_JC_LINE_NUMBER(40);				// 1
	_JC_REF_FIELD(env, r0, soot_util_dot_DotGraphAttribute, value) = r2;
	_JC_LINE_NUMBER(41);				// 2
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public java.lang.String toString()
//

static _jc_linenum _jc_soot_util_dot_DotGraphAttribute$linenum_table$toString$7ea43b33b80a3070[];

static const unsigned char _jc_soot_util_dot_DotGraphAttribute$param_ptypes$toString$7ea43b33b80a3070[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_soot_util_dot_DotGraphAttribute$method_info$toString$7ea43b33b80a3070 = {
	.name=			"toString",
	.signature=		"()Ljava/lang/String;",
	.class=			&_jc_soot_util_dot_DotGraphAttribute$type,
	.return_type=		&_jc_java_lang_String$type,
	.param_ptypes=		&_jc_soot_util_dot_DotGraphAttribute$param_ptypes$toString$7ea43b33b80a3070,
	.signature_hash=	_JC_JLONG(0x7ea43b33b80a3070),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_soot_util_dot_DotGraphAttribute$method$toString$7ea43b33b80a3070,
	.vtable_index=		_JC_OFFSETOF(struct _jc_soot_util_dot_DotGraphAttribute$vtable, soot_util_dot_DotGraphAttribute.toString$7ea43b33b80a3070) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	4,
	      .table=	_jc_soot_util_dot_DotGraphAttribute$linenum_table$toString$7ea43b33b80a3070
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(soot_util_dot_DotGraphAttribute, toString$7ea43b33b80a3070);

_jc_java_lang_String$object * _JC_JCNI_ATTR
_jc_soot_util_dot_DotGraphAttribute$method$toString$7ea43b33b80a3070(_jc_env *const env, _jc_soot_util_dot_DotGraphAttribute$object *this)
{
	struct _jc_soot_util_dot_DotGraphAttribute$object *r0;
	struct _jc_java_lang_StringBuffer$object *r1;
	struct _jc_java_lang_String$object *r2;
	_jc_char_array *r3;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	_JC_LINE_NUMBER(44);				// 0
	r1 = _JC_NEW(env, java_lang_StringBuffer);
	r3 = _JC_NEW_PRIM_ARRAY(env, char, 1, 16);
	_JC_REF_FIELD(env, r1, java_lang_StringBuffer, value) = r3;
	_JC_LINE_NUMBER(45);				// 1
	r2 = _JC_REF_FIELD(env, r0, soot_util_dot_DotGraphAttribute, id);
	_JC_INVOKE_NONVIRTUAL(env, java_lang_StringBuffer, append$7d7ff98bb1f0cb55, 0, r1, r2);
	_JC_INVOKE_NONVIRTUAL(env, java_lang_StringBuffer, append$7d7ff98bb1f0cb55, 0, r1, _JC_STRING(env, "="));
	_JC_LINE_NUMBER(47);				// 2
	r2 = _JC_REF_FIELD(env, r0, soot_util_dot_DotGraphAttribute, value);
	_JC_INVOKE_NONVIRTUAL(env, java_lang_StringBuffer, append$7d7ff98bb1f0cb55, 0, r1, r2);
	_JC_LINE_NUMBER(48);				// 3
	r2 = _JC_NEW(env, java_lang_String);
	_JC_INVOKE_NONVIRTUAL(env, java_lang_String, _init$aa54f0755ac8f3ce, 0, r2, r1);
	return r2;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_soot_util_dot_DotGraphAttribute$methods[] = {
	&_jc_soot_util_dot_DotGraphAttribute$method_info$_init$a34354cd9552963f,
	&_jc_soot_util_dot_DotGraphAttribute$method_info$toString$7ea43b33b80a3070
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_soot_util_dot_DotGraphAttribute$instanceof_hash_bucket_80[] = {
	&_jc_soot_util_dot_DotGraphAttribute$type,
	_JC_NULL
};
static _jc_type *const _jc_soot_util_dot_DotGraphAttribute$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_soot_util_dot_DotGraphAttribute$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[80]=	_jc_soot_util_dot_DotGraphAttribute$instanceof_hash_bucket_80,
	[101]=	_jc_soot_util_dot_DotGraphAttribute$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_soot_util_dot_DotGraphAttribute$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/lang/StringBuffer",	_JC_JLONG(0x94d357637b968dda) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_soot_util_dot_DotGraphAttribute$vtype _jc_soot_util_dot_DotGraphAttribute$type = {
    .type= {
	.name=			"soot/util/dot/DotGraphAttribute",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		12,
		.hash=			_JC_JLONG(0x28f908b461b109d0),
		.source_file=		"DotGraphAttribute.java",
		.instance_size=		sizeof(_jc_soot_util_dot_DotGraphAttribute$refs) + sizeof(_jc_soot_util_dot_DotGraphAttribute$object),
		.num_virtual_refs=	2,
		.num_fields=		sizeof(_jc_soot_util_dot_DotGraphAttribute$fields) / sizeof(*_jc_soot_util_dot_DotGraphAttribute$fields),
		.fields=		_jc_soot_util_dot_DotGraphAttribute$fields,
		.num_methods=		sizeof(_jc_soot_util_dot_DotGraphAttribute$methods) / sizeof(*_jc_soot_util_dot_DotGraphAttribute$methods),
		.methods=		_jc_soot_util_dot_DotGraphAttribute$methods,
		.instanceof_hash_table=	_jc_soot_util_dot_DotGraphAttribute$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_soot_util_dot_DotGraphAttribute$class_depends) / sizeof(*_jc_soot_util_dot_DotGraphAttribute$class_depends),
		.class_depends=		_jc_soot_util_dot_DotGraphAttribute$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=			// overridden
		&_jc_soot_util_dot_DotGraphAttribute$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.soot_util_dot_DotGraphAttribute= {
	    .toString$7ea43b33b80a3070=
		&_jc_soot_util_dot_DotGraphAttribute$method$toString$7ea43b33b80a3070,
	},
    }
};
